# -*- coding: utf-8 -*-

#
# Undent - Dedent and format multiline strings into human-readable output
#
# Ansgar Grunseid
# grunseid.com
# grunseid@gmail.com
#
# License: MIT
#

__title__ = 'undent'
__version__ = '0.2'
__license__ = 'MIT'
__author__ = 'Ansgar Grunseid'
__contact__ = 'grunseid@gmail.com'
__url__ = 'https://github.com/gruns/undent'
__description__ = (
    'Dedent and format multiline strings into human-readable output.')
